﻿<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
  <xsl:output method="html" indent="yes" doctype-public="-//W3C//DTD HTML 4.01//EN" />

  <xsl:variable name="bestPass">
    <xsl:choose>
      <xsl:when test="/optimizer-log/optimization-result/@pass-number">
        <xsl:value-of select="/optimizer-log/optimization-result/@pass-number" />
      </xsl:when>
      <xsl:otherwise>-1</xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <xsl:variable name="initialBalance">
    <xsl:for-each select="/optimizer-log/fixed-parameters/parameter">
      <xsl:choose>
        <xsl:when test="@name = 'initial-balance'">
          <xsl:value-of select="@value" />
        </xsl:when>
      </xsl:choose>
    </xsl:for-each>
  </xsl:variable>

  <xsl:template match="/">
    <html>
      <head>
        <META http-equiv="Content-Type" content="text/html; charset=UTF-8" />
        <TITLE>Optimizer results</TITLE>
        <style>
          body
          {
          font: 10px Arial;
          }

          table
          {
          border: 1px solid black;
          border-collapse: collapse;
          }

          td
          {
          border: 1px solid #cccccc;
          padding: 2px 5px 1px 5px;
          }

          th
          {
          background-color: #becdba;
          border: 1px solid #ffffff;
          padding: 2px 5px 1px 5px;
          height: 35px;
          }
          /* Sortable tables */
          table.sortable thead {
          background-color:#eee;
          color:#666666;
          font-weight: bold;
          cursor: default;
          }
        </style>
        <script src="http://ajax.googleapis.com/ajax/libs/jquery/2.0.3/jquery.min.js"></script>
        <script type="text/javascript" src="jquery.tablesorter.js"></script>
      </head>
      <body>
        <script type="text/javascript">$(document).ready(function(){$("#results").tablesorter();});</script>
        <xsl:apply-templates select="optimizer-log"/>
      </body>
    </html>
  </xsl:template>

  <xsl:template match="optimizer-log">
    <table id="results" class="tablesorter">
      <thead>
        <tr>
          <xsl:if test="/optimizer-log/passes/pass[1]/currency-pair">
            <th>Pair</th>
          </xsl:if>
          <xsl:if test="/optimizer-log/passes/pass[1]/timeframe">
            <th>TF</th>
          </xsl:if>
          <th>Pass</th>
          <th>Result</th>
          <xsl:if test="/optimizer-log/passes/pass[1]/optimizable-parameters-values/parameter">
            <xsl:for-each select="/optimizer-log/passes/pass[1]/optimizable-parameters-values/parameter">
              <th>
                <xsl:value-of select="@name" />
              </th>
            </xsl:for-each>
          </xsl:if>

          <xsl:if test="/optimizer-log/passes/pass[1]/statistics/output-parameter">
            <xsl:for-each select="/optimizer-log/passes/pass[1]/statistics/output-parameter">
              <th>
                <xsl:value-of select="@name" />
              </th>
            </xsl:for-each>
          </xsl:if>
        </tr>
      </thead>
      <tbody>
        <xsl:apply-templates select="passes"></xsl:apply-templates>
      </tbody>
    </table>
    <xsl:apply-templates select="errors"/>
  </xsl:template>

  <xsl:template match="passes">
    <xsl:apply-templates select="pass">
      <xsl:sort select="@result" order="descending" data-type="number" />
    </xsl:apply-templates>
  </xsl:template>

  <xsl:template match="pass">

    <xsl:if test="position() &lt; 501">
      <xsl:if test="statistics/output-parameter[@name = 'final-balance'][@value &gt; $initialBalance] or (currency-pair and timeframe)">
        <xsl:variable name="bgColor">
          <xsl:choose>
            <xsl:when test="position() &gt; 20">#FFA3B1</xsl:when>
            <xsl:when test="position() = 1">#99ddbb</xsl:when>
            <xsl:when test="@success = 'false'">#FFA3B1</xsl:when>
            <xsl:when test="statistics/output-parameter[@name = 'trade-count'][@value = 0]">#FFA3B1</xsl:when>
            <xsl:when test="statistics/output-parameter[@name = 'final-balance'][@value &lt; $initialBalance]">#FFA3B1</xsl:when>
            <xsl:when test="@number = $bestPass">#99ddbb</xsl:when>
            <xsl:when test="position() mod 2 = 0">#ffffff</xsl:when>
            <xsl:otherwise>#eeeeee</xsl:otherwise>
          </xsl:choose>
        </xsl:variable>
        <tr bgcolor="{$bgColor}">
          <xsl:if test="currency-pair">
            <td>
              <xsl:value-of select="currency-pair"/>
            </td>
          </xsl:if>
          <xsl:if test="timeframe">
            <td>
              <xsl:value-of select="timeframe"/>
            </td>
          </xsl:if>
          <td>
            <xsl:value-of select="@number"/>
          </td>
          <td>
            <xsl:value-of select="@result"/>
          </td>
          <xsl:apply-templates select="optimizable-parameters-values"/>
          <xsl:apply-templates select="statistics"/>
        </tr>
      </xsl:if>
    </xsl:if>
  </xsl:template>

  <xsl:template match="optimizable-parameters-values">
    <xsl:for-each select="parameter">
      <td>
        <xsl:variable name="varname">
          <xsl:value-of select="@name" />
        </xsl:variable>

        <xsl:variable name="varvalue">
          <xsl:value-of select="@value" />
        </xsl:variable>

        <xsl:choose>
          <xsl:when test="/optimizer-log/optimizable-parameters/optimizable-parameter[@name = $varname]/optimizable-parameters-alternatives/optimizable-parameters-alternative[@value=$varvalue]/@print-value" >
            <xsl:value-of select="/optimizer-log/optimizable-parameters/optimizable-parameter[@name = $varname]/optimizable-parameters-alternatives/optimizable-parameters-alternative[@value=$varvalue]/@print-value"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="$varvalue" />
          </xsl:otherwise>
        </xsl:choose>
      </td>
    </xsl:for-each>
  </xsl:template>

  <xsl:template match="statistics">
    <xsl:for-each select="output-parameter">
      <td>
        <xsl:value-of select="@value"/>
      </td>
    </xsl:for-each>

  </xsl:template>

  <xsl:template match="errors">
    <br />
    <br />
    <br />
    <table width="100%">
      <tr>
        <th>Error description</th>
      </tr>
      <xsl:for-each select="error">
        <tr>
          <td>
            <xsl:value-of select="." />
          </td>
        </tr>
      </xsl:for-each>
    </table>
  </xsl:template>
</xsl:stylesheet>
